@@ -10,7 +10,7 @@ from mmcv.utils import digit_version
 from torch.nn.modules.utils import _pair
 
 from ..builder import PIPELINES
-from .formating import to_tensor
+from .formatting import to_tensor
 
 
 def _combine_quadruple(a, b):
@@ -363,7 +363,7 @@ class Imgaug:
         """Default transforms for imgaug.
 
         Implement RandAugment by imgaug.
-        Plase visit `https://arxiv.org/abs/1909.13719` for more information.
+        Please visit `https://arxiv.org/abs/1909.13719` for more information.
 
         Augmenters and hyper parameters are borrowed from the following repo:
         https://github.com/tensorflow/tpu/blob/master/models/official/efficientnet/autoaugment.py # noqa
@@ -551,74 +551,6 @@ class Fuse:
         return results
 
 
-@PIPELINES.register_module()
-class RandomScale:
-    """Resize images by a random scale.
-
-    Required keys are "imgs", "img_shape", "modality", added or modified
-    keys are "imgs", "img_shape", "keep_ratio", "scale_factor", "lazy",
-    "scale", "resize_size". Required keys in "lazy" is None, added or
-    modified key is "interpolation".
-
-    Args:
-        scales (tuple[int]): Tuple of scales to be chosen for resize.
-        mode (str): Selection mode for choosing the scale. Options are "range"
-            and "value". If set to "range", The short edge will be randomly
-            chosen from the range of minimum and maximum on the shorter one
-            in all tuples. Otherwise, the longer edge will be randomly chosen
-            from the range of minimum and maximum on the longer one in all
-            tuples. Default: 'range'.
-    """
-
-    def __init__(self, scales, mode='range', **kwargs):
-        warnings.warn('"RandomScale" is deprecated and will be removed in '
-                      'later versions. It is currently not used in MMAction2')
-        self.mode = mode
-        if self.mode not in ['range', 'value']:
-            raise ValueError(f"mode should be 'range' or 'value', "
-                             f'but got {self.mode}')
-        self.scales = scales
-        self.kwargs = kwargs
-
-    def select_scale(self, scales):
-        num_scales = len(scales)
-        if num_scales == 1:
-            # specify a fixed scale
-            scale = scales[0]
-        elif num_scales == 2:
-            if self.mode == 'range':
-                scale_long = [max(s) for s in scales]
-                scale_short = [min(s) for s in scales]
-                long_edge = np.random.randint(
-                    min(scale_long),
-                    max(scale_long) + 1)
-                short_edge = np.random.randint(
-                    min(scale_short),
-                    max(scale_short) + 1)
-                scale = (long_edge, short_edge)
-            elif self.mode == 'value':
-                scale = random.choice(scales)
-        else:
-            if self.mode != 'value':
-                raise ValueError("Only 'value' mode supports more than "
-                                 '2 image scales')
-            scale = random.choice(scales)
-
-        return scale
-
-    def __call__(self, results):
-        scale = self.select_scale(self.scales)
-        results['scale'] = scale
-        resize = Resize(scale, **self.kwargs)
-        results = resize(results)
-        return results
-
-    def __repr__(self):
-        repr_str = (f'{self.__class__.__name__}('
-                    f'scales={self.scales}, mode={self.mode})')
-        return repr_str
-
-
 @PIPELINES.register_module()
 class RandomCrop:
     """Vanilla square random crop that specifics the output size.
@@ -1862,75 +1794,6 @@ class TenCrop:
         return repr_str
 
 
-@PIPELINES.register_module()
-class MultiGroupCrop:
-    """Randomly crop the images into several groups.
-
-    Crop the random region with the same given crop_size and bounding box
-    into several groups.
-    Required keys are "imgs", added or modified keys are "imgs", "crop_bbox"
-    and "img_shape".
-
-    Args:
-        crop_size(int | tuple[int]): (w, h) of crop size.
-        groups(int): Number of groups.
-    """
-
-    def __init__(self, crop_size, groups):
-        self.crop_size = _pair(crop_size)
-        self.groups = groups
-        if not mmcv.is_tuple_of(self.crop_size, int):
-            raise TypeError('Crop size must be int or tuple of int, '
-                            f'but got {type(crop_size)}')
-
-        if not isinstance(groups, int):
-            raise TypeError(f'Groups must be int, but got {type(groups)}.')
-
-        if groups <= 0:
-            raise ValueError('Groups must be positive.')
-
-    def __call__(self, results):
-        """Performs the MultiGroupCrop augmentation.
-
-        Args:
-            results (dict): The resulting dict to be modified and passed
-                to the next transform in pipeline.
-        """
-        if 'gt_bboxes' in results or 'proposals' in results:
-            warnings.warn('MultiGroupCrop cannot process bounding boxes')
-
-        imgs = results['imgs']
-        img_h, img_w = imgs[0].shape[:2]
-        crop_w, crop_h = self.crop_size
-
-        img_crops = []
-        crop_bboxes = []
-        for _ in range(self.groups):
-            x_offset = random.randint(0, img_w - crop_w)
-            y_offset = random.randint(0, img_h - crop_h)
-
-            bbox = [x_offset, y_offset, x_offset + crop_w, y_offset + crop_h]
-            crop = [
-                img[y_offset:y_offset + crop_h, x_offset:x_offset + crop_w]
-                for img in imgs
-            ]
-            img_crops.extend(crop)
-            crop_bboxes.extend([bbox for _ in range(len(imgs))])
-
-        crop_bboxes = np.array(crop_bboxes)
-        results['imgs'] = img_crops
-        results['crop_bbox'] = crop_bboxes
-        results['img_shape'] = results['imgs'][0].shape[:2]
-
-        return results
-
-    def __repr__(self):
-        repr_str = (f'{self.__class__.__name__}'
-                    f'(crop_size={self.crop_size}, '
-                    f'groups={self.groups})')
-        return repr_str
-
-
 @PIPELINES.register_module()
 class AudioAmplify:
     """Amplify the waveform.
@@ -1949,7 +1812,7 @@ class AudioAmplify:
             raise TypeError('Amplification ratio should be float.')
 
     def __call__(self, results):
-        """Perfrom the audio amplification.
+        """Perform the audio amplification.
 
         Args:
             results (dict): The resulting dict to be modified and passed
@@ -1975,8 +1838,8 @@ class MelSpectrogram:
     keys are "audios".
 
     Args:
-        window_size (int): The window size in milisecond. Default: 32.
-        step_size (int): The step size in milisecond. Default: 16.
+        window_size (int): The window size in millisecond. Default: 32.
+        step_size (int): The step size in millisecond. Default: 16.
         n_mels (int): Number of mels. Default: 80.
         fixed_length (int): The sample length of melspectrogram maybe not
             exactly as wished due to different fps, fix the length for batch
