@@ -11,6 +11,7 @@ from .resnet3d_slowonly import ResNet3dSlowOnly
 from .resnet_audio import ResNetAudio
 from .resnet_tin import ResNetTIN
 from .resnet_tsm import ResNetTSM
+from .stgcn import STGCN
 from .tanet import TANet
 from .timesformer import TimeSformer
 from .x3d import X3D
@@ -19,5 +20,5 @@ __all__ = [
     'C3D', 'ResNet', 'ResNet3d', 'ResNetTSM', 'ResNet2Plus1d',
     'ResNet3dSlowFast', 'ResNet3dSlowOnly', 'ResNet3dCSN', 'ResNetTIN', 'X3D',
     'ResNetAudio', 'ResNet3dLayer', 'MobileNetV2TSM', 'MobileNetV2', 'TANet',
-    'TimeSformer'
+    'TimeSformer', 'STGCN'
 ]
